# Table of Contents

- [mapping-sap-signavio-processes-to-fact-sheets](<./mapping-sap-signavio-processes-to-fact-sheets.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
- [Mapping SAP Signavio Processes to Fact Sheets](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets.md>)
  - [Introduction](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Introduction.md>)
  - [Mapping Processes](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Mapping-Processes.md>)
  - [Choosing Sync Mode](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Choosing-Sync-Mode.md>)
  - [Configuring the Process Synchronization Hierarchy](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Configuring-the-Process-Synchronization-Hierarchy.md>)
  - [Choosing Process Hierarchy Relation](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Choosing-Process-Hierarchy-Relation.md>)
  - [Configuring Interval-Based Synchronization](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Configuring-Interval-Based-Synchronization.md>)
  - [Activating and Deactivating Mapped Processes](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Activating-and-Deactivating-Mapped-Processes.md>)
  - [Mapping Process Attributes to Fact Sheet Attributes](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Mapping-Process-Attributes-to-Fact-Sheet-Attributes.md>)
  - [Value Mapping](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Value-Mapping.md>)
  - [Adding Documentation](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Adding-Documentation.md>)
  - [Mapping Processes to Fact Sheet Subtypes](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Mapping-Processes-to-Fact-Sheet-Subtypes.md>)
  - [Was this page helpful?](<./Mapping-SAP-Signavio-Processes-to-Fact-Sheets/Was-this-page-helpful.md>)
